@@ -81,14 +81,20 @@ save_config(char *path, Options *opts)
 	if (f == NULL)
 		return false;
 
+	fprintf(f, "ascii_menu = %s\n", opts->force_ascii_art ? "true" : "false");
 	fprintf(f, "ignore_case = %s\n", opts->ignore_case ? "true" : "false");
 	fprintf(f, "ignore_lower_case = %s\n", opts->ignore_lower_case ? "true" : "false");
+	fprintf(f, "no_cursor = %s\n", opts->no_cursor ? "true" : "false");
 	fprintf(f, "no_sound = %s\n", opts->no_sound ? "true" : "false");
+	fprintf(f, "no_mouse = %s\n", opts->no_mouse ? "true" : "false");
 	fprintf(f, "less_status_bar = %s\n", opts->less_status_bar ? "true" : "false");
 	fprintf(f, "no_highlight_search = %s\n", opts->no_highlight_search ? "true" : "false");
 	fprintf(f, "no_highlight_lines = %s\n", opts->no_highlight_lines ? "true" : "false");
 	fprintf(f, "force_uniborder = %s\n", opts->force_uniborder ? "true" : "false");
+	fprintf(f, "show_rownum = %s\n", opts->show_rownum ? "true" : "false");
 	fprintf(f, "theme = %d\n", opts->theme);
+	fprintf(f, "without_commandbar = %s\n", opts->no_commandbar ? "true" : "false");
+	fprintf(f, "without_topbar = %s\n", opts->no_topbar ? "true" : "false");
 
 	fclose(f);
 
@@ -120,12 +126,18 @@ load_config(char *path, Options *opts)
 
 		if (parse_cfg(line, key, &bool_val, &int_val))
 		{
+			if (strcmp(key, "ascii_menu") == 0)
+				opts->force_ascii_art = bool_val;
 			if (strcmp(key, "ignore_case") == 0)
 				opts->ignore_case = bool_val;
 			else if (strcmp(key, "ignore_lower_case") == 0)
 				opts->ignore_lower_case = bool_val;
 			else if (strcmp(key, "no_sound") == 0)
 				opts->no_sound = bool_val;
+			else if (strcmp(key, "no_cursor") == 0)
+				opts->no_cursor = bool_val;
+			else if (strcmp(key, "no_mouse") == 0)
+				opts->no_mouse = bool_val;
 			else if (strcmp(key, "less_status_bar") == 0)
 				opts->less_status_bar = bool_val;
 			else if (strcmp(key, "no_highlight_search") == 0)
@@ -134,8 +146,14 @@ load_config(char *path, Options *opts)
 				opts->no_highlight_lines = bool_val;
 			else if (strcmp(key, "force_uniborder") == 0)
 				opts->force_uniborder = bool_val;
+			else if (strcmp(key, "show_rownum") == 0)
+				opts->show_rownum = bool_val;
 			else if (strcmp(key, "theme") == 0)
 				opts->theme = int_val;
+			else if (strcmp(key, "without_commandbar") == 0)
+				opts->no_commandbar = bool_val;
+			else if (strcmp(key, "without_topbar") == 0)
+				opts->no_topbar = bool_val;
 
 			free(line);
 			line = NULL;
