@@ -28,6 +28,12 @@ typedef struct
 	bool	no_highlight_lines;
 	bool	force_uniborder;
 	bool	force8bit;
+	bool	no_commandbar;
+	bool	no_topbar;
+	bool	show_rownum;
+	bool	no_cursor;
+	bool	tabular_cursor;
+	bool	force_ascii_art;
 	int		theme;
 	int		freezed_cols;
 } Options;
