@@ -33,18 +33,23 @@ window_fill(int window_identifier,
 	LineBuffer *lnb = &desc->rows;
 	int			lnb_row;
 	attr_t		active_attr;
+	attr_t		pattern_fix;
 	int			srcy_bak = srcy;
 	char		*free_row;
 	WINDOW		*win;
 	Theme		*t;
 	bool		is_footer = window_identifier == WINDOW_FOOTER;
 	bool		is_fix_rows = window_identifier == WINDOW_LUC || window_identifier == WINDOW_FIX_ROWS;
+	bool		is_rownum = window_identifier == WINDOW_ROWNUM;
+	bool		is_rownum_luc = window_identifier == WINDOW_ROWNUM_LUC;
 	int			positions[100][2];
 	int			npositions;
 
 	win = scrdesc->wins[window_identifier];
 	t = &scrdesc->themes[window_identifier];
 
+	pattern_fix = t->found_str_attr & A_UNDERLINE;
+
 	/* when we want to detect expanded records titles */
 	if (desc->is_expanded_mode)
 	{
@@ -56,6 +61,13 @@ window_fill(int window_identifier,
 	if (win == NULL)
 		return;
 
+	if (is_rownum_luc)
+	{
+		/* just clean */
+		werase(win);
+		return;
+	}
+
 	/* skip first x LineBuffers */
 	while (srcy > 1000)
 	{
@@ -78,8 +90,9 @@ window_fill(int window_identifier,
 		bool		is_cursor_row = false;
 		bool		is_found_row = false;
 		bool		is_pattern_row = false;
+		char		buffer[10];
 
-		is_cursor_row = row == cursor_row;
+		is_cursor_row = (!opts->no_cursor && row == cursor_row);
 
 		if (lnb_row == 1000)
 		{
@@ -95,6 +108,15 @@ window_fill(int window_identifier,
 			else
 				lineinfo = NULL;
 			lnb_row += 1;
+
+			/* when rownum is printed, don't process original text */
+			if (is_rownum)
+			{
+				int rowno = row + srcy_bak + 1 - desc->first_data_row;
+
+				snprintf(buffer, sizeof(buffer), "%*d ", maxx - 1, rowno);
+				rowstr = buffer;
+			}
 		}
 		else
 			rowstr = NULL;
@@ -208,9 +230,11 @@ window_fill(int window_identifier,
 			}
 		}
 
+		active_attr = 0;
+
 		if (is_bookmark_row)
 		{
-			if (!is_footer)
+			if (!is_footer && !is_rownum)
 			{
 				if (desc->border_type == 2)
 					active_attr = is_cursor_row ? t->cursor_bookmark_attr : t->bookmark_line_attr;
@@ -220,7 +244,8 @@ window_fill(int window_identifier,
 			else
 				active_attr = is_cursor_row ? t->cursor_bookmark_attr : t->bookmark_data_attr;
 		}
-		else if (is_pattern_row)
+		/* would not to show pattern colors in rownum window */
+		else if (is_pattern_row && !is_rownum)
 		{
 			if (!is_footer)
 			{
@@ -234,7 +259,7 @@ window_fill(int window_identifier,
 		}
 		else
 		{
-			if (!is_footer)
+			if (!is_footer && !is_rownum)
 			{
 				if (desc->border_type == 2)
 					active_attr = is_cursor_row ? t->cursor_line_attr : t->line_attr;
@@ -249,6 +274,13 @@ window_fill(int window_identifier,
 
 		wmove(win, row++, 0);
 
+		if (is_rownum)
+		{
+			waddstr(win, rowstr);
+			wattroff(win, active_attr);
+			continue;
+		}
+
 		if (rowstr != NULL)
 		{
 			int		i;
@@ -442,7 +474,7 @@ window_fill(int window_identifier,
 						{
 							if (is_found_row && htrpos >= scrdesc->found_start_x &&
 									htrpos < scrdesc->found_start_x + scrdesc->searchterm_char_size)
-								new_attr = new_attr ^ A_REVERSE;
+								new_attr = new_attr ^ A_REVERSE | pattern_fix;
 							else if (is_pattern_row && htrpos >= lineinfo->start_char)
 							{
 								if ((lineinfo->mask & LINEINFO_FOUNDSTR_MULTI) != 0)
@@ -924,6 +956,8 @@ draw_rectange(int offsety, int offsetx,			/* y, x offset on screen */
 	}
 }
 
+#define FIXVTE		1
+
 void
 draw_data(Options *opts, ScrDesc *scrdesc, DataDesc *desc,
 		  int first_data_row, int first_row, int cursor_col,
@@ -931,32 +965,39 @@ draw_data(Options *opts, ScrDesc *scrdesc, DataDesc *desc,
 {
 	struct winsize size;
 	int		i;
+	int		nrows;
 
 	if (ioctl(0, TIOCGWINSZ, (char *) &size) >= 0)
 	{
-
 		for (i = 0; i < min_int(size.ws_row - 1 - scrdesc->top_bar_rows, desc->last_row + 1); i++)
 			printf("\eD");
 
 		/* Go wit cursor to up */
 		printf("\e[%dA", min_int(size.ws_row - 1 - scrdesc->top_bar_rows, desc->last_row + 1));
 
-		/* Save cursor */
+		/*
+		 * Save cursor - Attention, there are a Fedora29 bug, and it doesn't work
+		 */
 		printf("\e[s");
 
 		if (scrdesc->fix_cols_cols > 0)
 		{
 			draw_rectange(scrdesc->fix_rows_rows, 0,
-						  scrdesc->rows_rows , scrdesc->fix_cols_cols,
+						  scrdesc->rows_rows, scrdesc->fix_cols_cols,
 						  first_data_row + first_row - fix_rows_offset, 0,
 						  opts, desc,
 						  COLOR_PAIR(4) | A_BOLD, 0, COLOR_PAIR(8) | A_BOLD,
 						  false);
+			nrows = scrdesc->fix_rows_rows + scrdesc->rows_rows;
 		}
-		if (scrdesc->fix_rows_rows > 0)
+		if (scrdesc->fix_rows_rows > 0 )
 		{
-			/* Go to saved position */
-			printf("\e[u\e[s");
+			if (FIXVTE)
+				/* Go wit cursor to up */
+				printf("\e[%dA", nrows);
+			else
+				/* Go to saved position */
+				printf("\e[u\e[s");
 
 			draw_rectange(0, scrdesc->fix_cols_cols,
 						  scrdesc->fix_rows_rows, size.ws_col - scrdesc->fix_cols_cols,
@@ -964,12 +1005,17 @@ draw_data(Options *opts, ScrDesc *scrdesc, DataDesc *desc,
 						  opts, desc,
 						  COLOR_PAIR(4) | A_BOLD, 0, COLOR_PAIR(8) | A_BOLD,
 						  true);
+			nrows = 0 + scrdesc->fix_rows_rows;
 		}
 
 		if (scrdesc->fix_rows_rows > 0 && scrdesc->fix_cols_cols > 0)
 		{
-			/* Go to saved position */
-			printf("\e[u\e[s");
+			if (FIXVTE)
+				/* Go wit cursor to up */
+				printf("\e[%dA", nrows);
+			else
+				/* Go to saved position */
+				printf("\e[u\e[s");
 
 			draw_rectange(0, 0,
 						  scrdesc->fix_rows_rows, scrdesc->fix_cols_cols,
@@ -977,12 +1023,18 @@ draw_data(Options *opts, ScrDesc *scrdesc, DataDesc *desc,
 						  opts, desc,
 						  COLOR_PAIR(4) | A_BOLD, 0, COLOR_PAIR(8) | A_BOLD,
 						  false);
+
+			nrows = 0 + scrdesc->fix_rows_rows;
 		}
 
-		if (scrdesc->rows_rows > 0 )
+		if (scrdesc->rows_rows > 0)
 		{
-			/* Go to saved position */
-			printf("\e[u\e[s");
+			if (FIXVTE)
+				/* Go wit cursor to up */
+				printf("\e[%dA", nrows);
+			else
+				/* Go to saved position */
+				printf("\e[u\e[s");
 
 			draw_rectange(scrdesc->fix_rows_rows, scrdesc->fix_cols_cols,
 						  scrdesc->rows_rows, size.ws_col - scrdesc->fix_cols_cols,
@@ -996,8 +1048,12 @@ draw_data(Options *opts, ScrDesc *scrdesc, DataDesc *desc,
 
 		if (w_footer(scrdesc) != NULL)
 		{
-			/* Go to saved position */
-			printf("\e[u\e[s");
+			if (FIXVTE)
+				/* Go wit cursor to up */
+				printf("\e[%dA", nrows);
+			else
+				/* Go to saved position */
+				printf("\e[u\e[s");
 
 			draw_rectange(scrdesc->fix_rows_rows + scrdesc->rows_rows, 0,
 						  scrdesc->footer_rows, scrdesc->maxx,
