@@ -17,13 +17,20 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 	config->mark_tag = '*';
 	config->draw_box = true;
 	config->extern_accel_text_space = 2;
+	config->force_ascii_art = false;
 
 	config->submenu_offset_y = 0;
 	config->submenu_offset_x = 0;
 
+#if defined  HAVE_NCURSESW
+
 	if (!config->force8bit)
 		config->mark_tag = L'\x2714';
 
+#endif
+
+	config->funckey_bar_style = false;
+
 	switch (style)
 	{
 		case ST_MENU_STYLE_MCB:
@@ -31,6 +38,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -60,6 +71,8 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_bar_menu_offset = 0;
 			config->shadow_width = 0;
 
+			config->funckey_bar_style = true;
+
 			break;
 
 		case ST_MENU_STYLE_MC:
@@ -67,6 +80,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = A_BOLD;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_CYAN);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -96,7 +113,9 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->text_space = 5;
 			config->init_text_space = 2;
 			config->menu_bar_menu_offset = 0;
-			config->shadow_width = 0;
+			config->shadow_width = 2;
+
+			config->funckey_bar_style = true;
 
 			break;
 
@@ -105,6 +124,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -149,6 +172,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -187,6 +214,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -228,6 +259,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -269,6 +304,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -308,6 +347,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -348,6 +391,9 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_cpn = 0;
 			config->menu_background_attr = 0;
 
+			config->menu_unfocused_cpn = 0;
+			config->menu_unfocused_attr = 0;
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = A_REVERSE;
 
@@ -380,6 +426,9 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_cpn = start_from_cpn;
 			config->menu_background_attr = 0;
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = A_REVERSE;
 
@@ -418,6 +467,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -456,6 +509,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -494,6 +551,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = A_BOLD;
 			init_pair(start_from_cpn++, COLOR_YELLOW, COLOR_BLUE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = A_BOLD;
+			init_pair(start_from_cpn++, COLOR_YELLOW, COLOR_BLUE);
+
 			config->accelerator_cpn = start_from_cpn;
 			config->accelerator_attr = A_BOLD;
 			init_pair(start_from_cpn++, COLOR_CYAN, COLOR_BLUE);
@@ -528,6 +589,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_WHITE);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -567,6 +632,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -606,6 +675,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = 0;
 			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = 0;
+			init_pair(start_from_cpn++, COLOR_BLACK, COLOR_CYAN);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
@@ -637,6 +710,8 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_bar_menu_offset = 0;
 			config->shadow_width = 0;
 
+			config->funckey_bar_style = true;
+
 			break;
 
 		case ST_MENU_STYLE_DBASE:
@@ -644,6 +719,10 @@ st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
 			config->menu_background_attr = A_BOLD;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
 
+			config->menu_unfocused_cpn = start_from_cpn;
+			config->menu_unfocused_attr = A_BOLD;
+			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
+
 			config->menu_shadow_cpn = start_from_cpn;
 			config->menu_shadow_attr = 0;
 			init_pair(start_from_cpn++, COLOR_WHITE, COLOR_BLACK);
