@@ -38,6 +38,16 @@ if_notin_int(int v, const int *s, int v1, int v2)
 	return v1;
 }
 
+/* 0..255 rgb based colors */
+static void
+init_color_rgb_ff(short color, short r, short g, short b)
+{
+	init_color(color,
+			   (r / 255.0) * 1000.0,
+			   (g / 255.0) * 1000.0,
+			   (b / 255.0) * 1000.0);
+}
+
 /*
  * Set color pairs based on style
  */
@@ -70,6 +80,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, -1, -1);		/* color of marked search pattern in no-hl line mode */
 			init_pair(19, -1, -1);		/* color of marked search pattern in cursor */
 			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			init_pair(21, -1, -1);							/* rownum colors */
 
 			break;
 		case 1:
@@ -94,6 +105,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_GREEN, COLOR_BLUE);
 			init_pair(19, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			init_pair(21, COLOR_WHITE, COLOR_CYAN);
 			break;
 		case 2:
 			assume_default_colors(COLOR_WHITE, COLOR_CYAN);
@@ -117,7 +129,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_YELLOW, COLOR_GREEN);
 			init_pair(19, COLOR_YELLOW, COLOR_BLUE);
 			init_pair(20, COLOR_WHITE, COLOR_BLACK);
-
+			init_pair(21, COLOR_WHITE, COLOR_CYAN);
 			break;
 		case 3:
 			assume_default_colors(COLOR_BLACK, COLOR_CYAN);
@@ -141,6 +153,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_WHITE, COLOR_GREEN);
 			init_pair(19, COLOR_YELLOW, COLOR_BLACK);
 			init_pair(20, COLOR_WHITE, COLOR_BLUE);
+			init_pair(21, COLOR_BLACK, COLOR_CYAN);
 
 			break;
 		case 4:
@@ -237,6 +250,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_CYAN, COLOR_BLACK);
 			init_pair(19, COLOR_CYAN, COLOR_GREEN);
 			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			init_pair(21, COLOR_CYAN, COLOR_BLACK);
 
 			break;
 		case 8:
@@ -261,6 +275,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_CYAN, COLOR_BLUE);
 			init_pair(19, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(20, COLOR_YELLOW, COLOR_BLACK);
+			init_pair(21, COLOR_CYAN, COLOR_BLUE);
 
 			break;
 		case 9:
@@ -285,6 +300,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_YELLOW, COLOR_BLUE);
 			init_pair(19, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(20, COLOR_YELLOW, COLOR_BLACK);
+			init_pair(21, COLOR_WHITE, COLOR_BLUE);
 
 			break;
 		case 10:
@@ -309,6 +325,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(19, COLOR_YELLOW, COLOR_BLUE);
 			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			init_pair(21, COLOR_BLUE, COLOR_CYAN);
 
 			break;
 		case 11:
@@ -357,6 +374,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_YELLOW, COLOR_CYAN);
 			init_pair(19, COLOR_CYAN, COLOR_BLUE);
 			init_pair(20, COLOR_WHITE, COLOR_MAGENTA);
+			init_pair(21, COLOR_CYAN, COLOR_CYAN);
 
 			break;
 		case 13:
@@ -405,6 +423,7 @@ initialize_color_pairs(int theme)
 			init_pair(18, COLOR_CYAN, COLOR_BLUE);
 			init_pair(19, COLOR_WHITE, COLOR_CYAN);
 			init_pair(20, COLOR_WHITE, COLOR_BLACK);
+			init_pair(21, COLOR_WHITE, COLOR_BLUE);
 			break;
 
 		case 15:
@@ -453,10 +472,118 @@ initialize_color_pairs(int theme)
 			init_pair(18, -1, -1);
 			init_pair(19, -1, -1);
 			init_pair(20, -1, -1);
+			init_pair(21, -1, -1);
 			break;
 
-	}
+		case 17:
+			init_color(235, 27, 212, 259);
+			init_color(234, 0, 169, 212);
+			init_color(240, 345, 431, 459);
+			init_color(244, 557, 616, 624);
+			init_color(245, 576, 631, 631);
+			init_color(254, 933, 910, 835);
+			init_color(136, 710, 537, 0);
+			init_color(33, 149, 545, 824);
+			init_color(160, 863, 196, 184);
 
+			assume_default_colors(245, 234);
+
+			init_pair(2, 245, 235);
+			init_pair(3, 244, 234);
+			init_pair(4, 33, 234);
+			init_pair(5, 235, 136);
+			init_pair(6, 235, 136);
+			init_pair(7, 33, 235);
+			init_pair(8, 33, 235);
+			init_pair(9, 61, 234);
+			init_pair(10, 235, 136);
+			init_pair(11, 235, 136);
+			init_pair(12, -1, -1);
+			init_pair(13, -1, -1);
+			init_pair(14, 230, 160);
+			init_pair(15, 254, 235);
+			
+			init_pair(16, 245, 235);
+			init_pair(17, 245, 235);
+			
+			init_pair(18, -1, -1);
+			init_pair(19, -1, -1);
+			init_pair(20, 254, 136);
+			init_pair(21, 244, 235);
+			break;
+
+		case 18:
+			init_color(234, 13, 98, 119);
+			init_color(235, 18, 141, 172);
+			init_color(240, 110, 146, 200);
+			init_color(245, 576, 631, 631);
+			init_color(244, 557, 616, 624);
+			init_color(136, 710, 537, 0);
+			init_color(160, 863, 196, 184);
+
+			assume_default_colors(234, 245);
+
+			init_pair(2, 235, 244);
+			init_pair(3, 234, 245);
+			init_pair(4, 17, 245);
+			init_pair(5, 235, 136);
+			init_pair(6, 235, 136);
+			init_pair(7, 17, 244);
+			init_pair(8, 17, 235);
+			init_pair(9, 17, 245);
+			init_pair(10, 235, 136);
+			init_pair(11, 235, 136);
+			init_pair(12, -1, -1);
+			init_pair(13, -1, -1);
+			init_pair(14, 255, 160);
+			init_pair(15, 255, 244);
+			init_pair(16, 240, 244);
+			init_pair(17, 240, 244);
+			init_pair(18, -1, -1);
+			init_pair(19, -1, -1);
+			init_pair(20, 255, 136);
+			init_pair(21, 235, 244);
+			break;
+
+		case 19:
+			init_color_rgb_ff(200, 0xff, 0xff, 0xd7); /* background */
+			init_color_rgb_ff(201, 0x26, 0x26, 0x26); /* foreground */
+			init_color_rgb_ff(202, 0xaf, 0xaf, 0x87); /* modeline bg */
+			init_color_rgb_ff(203, 0x4e, 0x4e, 0x4e); /* modeline fg */
+			init_color_rgb_ff(204, 0xd7, 0xd6, 0xaf); /* table decor */
+			init_color_rgb_ff(205, 0xeb, 0xdb, 0xb2); /* cursor bg */
+			init_color_rgb_ff(206, 0xaf, 0xaf, 0xaf); /* footer */
+			init_color_rgb_ff(207, 0xff, 0xff, 0xaf); /* lineno bg */
+
+			init_color_rgb_ff(210, 0x87, 0x00, 0x00); /* keyword - red */
+			init_color_rgb_ff(211, 0Xd7, 0x5f, 0x5f); /* bookmark - faded red */
+			init_color_rgb_ff(212, 0x00, 0x5f, 0x87); /* mark - faded blue */
+
+			init_color(240, 40, 50, 200);
+
+			assume_default_colors(204, 200);
+
+			init_pair(2, 203, 202);
+			init_pair(3, 201, 200);
+			init_pair(4, 210, 200);
+			init_pair(5, 210, 205);
+			init_pair(6, 203, 205);
+			init_pair(7, 203, 202);
+			init_pair(8, 17, 200);
+			init_pair(9, 206, 200);
+			init_pair(10, 206, 205);
+			init_pair(11, 204, 205);
+			init_pair(13, 203, 202);
+			init_pair(14, COLOR_WHITE, 211);
+			init_pair(15, 212, 204);
+			init_pair(16, 201, 204);
+			init_pair(17, 206, 204);
+			init_pair(18, -1, -1);
+			init_pair(19, -1, -1);
+			init_pair(20, 212, 205);
+			init_pair(21, 206, 207);
+			break;
+	}
 }
 
 #define _in			if_in_int
@@ -476,7 +603,7 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 		case WINDOW_LUC:
 		case WINDOW_FIX_ROWS:
 			t->data_attr = COLOR_PAIR(4);
-			t->data_attr |= _notin(theme, (int[]) {12, 15, -1}, A_BOLD, 0);
+			t->data_attr |= _notin(theme, (int[]) {12, 15, 19, -1}, A_BOLD, 0);
 			t->data_attr |= _in(theme, (int[]) {15, -1}, A_DIM, 0);
 			t->data_attr |= _in(theme, (int[]) {16, -1}, A_ITALIC, 0);
 			break;
@@ -491,7 +618,7 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->bottom_attr = COLOR_PAIR(12);
 			t->bottom_light_attr = COLOR_PAIR(13);
 
-			t->prompt_attr |= _notin(theme, (int[]) {0, 1, -1}, A_BOLD, 0);
+			t->prompt_attr |= _notin(theme, (int[]) {0, 1, 19, -1}, A_BOLD, 0);
 			t->bottom_attr |= _notin(theme, (int[]) {13, 14, -1}, A_BOLD, 0);
 			t->bottom_light_attr |= A_BOLD;
 			break;
@@ -511,7 +638,7 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->pattern_data_attr = COLOR_PAIR(16);
 			t->pattern_line_attr = COLOR_PAIR(17);
 
-			t->data_attr |= _notin(theme, (int[]) { 12, 15, -1}, A_BOLD, 0);
+			t->data_attr |= _notin(theme, (int[]) { 12, 15, 19, -1}, A_BOLD, 0);
 			t->data_attr |= _in(theme, (int[]) {15, -1}, A_DIM, 0);
 			t->line_attr |= 0;
 			t->expi_attr |= A_BOLD;
@@ -525,7 +652,8 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : _in(theme, (int[]){0, 15,  -1}, A_REVERSE | A_BOLD, A_BOLD);
 			t->pattern_data_attr |= _in(theme, (int[]) {15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
 			t->pattern_line_attr |= _in(theme, (int[]) {11, 7, 8, 15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
-
+			t->found_str_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE | (no_highlight_lines ? A_ITALIC : 0), 0);
+			t->cursor_pattern_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE | A_REVERSE, 0);
 			t->cursor_data_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
 			t->cursor_line_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
 			t->data_attr |= _in(theme, (int[]) {16, -1}, A_ITALIC, 0);
@@ -561,7 +689,8 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->found_str_attr |= no_highlight_lines ? (_in(theme, (int[]){0, -1}, A_REVERSE, A_BOLD)) : _in(theme, (int[]){0, 15,  -1}, A_REVERSE | A_BOLD, A_BOLD);
 			t->pattern_data_attr |= _in(theme, (int[]) {15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
 			t->pattern_line_attr |= _in(theme, (int[]) {11, 7, 8, 15, -1}, A_BOLD, 0) | _in(theme, (int[]) {0, 15, -1}, A_REVERSE, 0);
-
+			t->found_str_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
+			t->cursor_pattern_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE | A_REVERSE, 0);
 			t->cursor_data_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
 			t->cursor_line_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
 			t->bookmark_data_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
@@ -598,6 +727,24 @@ initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_
 			t->pattern_line_attr |= 0;
 			t->cursor_pattern_attr |= A_REVERSE;
 			break;
+
+		case WINDOW_ROWNUM:
+		case WINDOW_ROWNUM_LUC:
+			t->data_attr = COLOR_PAIR(21);
+			t->cursor_data_attr = COLOR_PAIR(10);
+			t->bookmark_data_attr = COLOR_PAIR(14);
+			t->cursor_bookmark_attr = COLOR_PAIR(14);
+			t->pattern_data_attr = COLOR_PAIR(16);
+
+			t->data_attr |= _in(theme, (int[]) { 1, 2, 12, 13, 14, -1}, A_BOLD,0);
+			t->cursor_data_attr |= _notin(theme, (int[]) {14, 1, -1}, A_BOLD, 0);
+			t->bookmark_data_attr |= _in(theme, (int[]){15, -1}, A_REVERSE | A_BOLD, A_BOLD);
+			t->cursor_bookmark_attr |= A_BOLD | A_REVERSE;
+
+			t->cursor_data_attr |= _in(theme, (int[]) {16, -1}, A_REVERSE, 0);
+			t->bookmark_data_attr |= _in(theme, (int[]) {16, -1}, A_UNDERLINE, 0);
+
+			break;
 	}
 
 	if (no_highlight_lines)
