@@ -48,6 +48,9 @@ utf8len_start_stop(const char *start, const char *stop)
 int
 utf8charlen(char ch)
 {
+	if ((ch & 0x80) == 0)
+		return 1;
+
 	if ((ch & 0xF0) == 0xF0)
 		return 4;
 
@@ -101,7 +104,6 @@ mbbisearch(wchar_t ucs, const struct mbinterval *table, int max)
 	return 0;
 }
 
-
 /* The following functions define the column width of an ISO 10646
  * character as follows:
  *
@@ -203,6 +205,50 @@ ucs_wcwidth(wchar_t ucs)
 		  (ucs >= 0x20000 && ucs <= 0x2ffff)));
 }
 
+/*
+ * Map a Unicode code point to UTF-8.  utf8string must have 4 bytes of
+ * space allocated.
+ */
+unsigned char *
+unicode_to_utf8(wchar_t c, unsigned char *utf8string, int *size)
+{
+	int		_size;
+
+	if (c <= 0x7F)
+	{
+		utf8string[0] = c;
+		_size = 1;
+	}
+	else if (c <= 0x7FF)
+	{
+		utf8string[0] = 0xC0 | ((c >> 6) & 0x1F);
+		utf8string[1] = 0x80 | (c & 0x3F);
+		_size = 2;
+	}
+	else if (c <= 0xFFFF)
+	{
+		utf8string[0] = 0xE0 | ((c >> 12) & 0x0F);
+		utf8string[1] = 0x80 | ((c >> 6) & 0x3F);
+		utf8string[2] = 0x80 | (c & 0x3F);
+		_size = 3;
+	}
+	else
+	{
+		utf8string[0] = 0xF0 | ((c >> 18) & 0x07);
+		utf8string[1] = 0x80 | ((c >> 12) & 0x3F);
+		utf8string[2] = 0x80 | ((c >> 6) & 0x3F);
+		utf8string[3] = 0x80 | (c & 0x3F);
+		_size = 4;
+	}
+
+	if (size != NULL)
+		*size = _size;
+
+	return utf8string;
+}
+
+
+
 /*
  * Convert a UTF-8 character to a Unicode code point.
  * This is a one-character version of pg_utf2wchar_with_len.
@@ -237,6 +283,58 @@ utf_dsplen(const char *s)
 	return ucs_wcwidth(utf8_to_unicode((const unsigned char *) s));
 }
 
+/*
+ * Returns display length of \0 ended multibyte string.
+ * The string is limited by max_bytes too.
+ */
+int
+utf_string_dsplen(const char *s, size_t max_bytes)
+{
+	int result = 0;
+	const char *ptr = s;
+
+	while (*ptr != '\0' && max_bytes > 0)
+	{
+		int		clen = utf8charlen(*ptr);
+
+		result += utf_dsplen(ptr);
+		ptr += clen;
+		max_bytes -= clen;
+	}
+
+	return result;
+}
+
+/*
+ * This version of previous function uses similar calculation like
+ * readline libarry - and supports terminal tabs.
+ *
+ * This code is based on demo ulfalizer/readline-and-ncurses
+ *
+ */
+int
+readline_utf_string_dsplen(const char *s, size_t max_bytes, size_t offset)
+{
+	int result = 0;
+	const char *ptr = s;
+
+	while (*ptr != '\0' && max_bytes > 0)
+	{
+		int		clen = utf8charlen(*ptr);
+		int		dsplen = utf_dsplen(ptr);
+
+		if (dsplen > 0)
+			result += dsplen;
+		else if (*ptr == '\t')
+			result = ((result + offset + 8) & ~7) - offset;
+
+		ptr += clen;
+		max_bytes -= clen;
+	}
+
+	return result;
+}
+
 /*
  * following code is taken from starwing/luautf8 library.
  *
@@ -305,7 +403,7 @@ find_in_range(range_table *t, size_t size, wchar_t ucs)
 
 #define table_size(t) (sizeof(t)/sizeof((t)[0]))
 
-static int
+int
 utf8_tofold(const char *s)
 {
 	static struct conv_table tofold_table[] = {
@@ -378,7 +476,7 @@ utf8_nstrstr(const char *haystack, const char *needle)
 {
 	const char *haystack_cur, *needle_cur, *needle_prev;
 	int		f1 = 0, f2 = 0;
-	int		needle_char_len;
+	int		needle_char_len = 0; /* be compiler quiet */
 
 	needle_cur = needle;
 	needle_prev = NULL;
@@ -429,9 +527,9 @@ utf8_nstrstr_ignore_lower_case(const char *haystack, const char *needle)
 
 	while (*needle_cur != '\0')
 	{
-		int		needle_char_len;
 		int		haystack_char_len;
-		bool	needle_char_is_upper;
+		int		needle_char_len = 0;
+		bool	needle_char_is_upper =  false;
 
 		if (*haystack_cur == '\0')
 			return NULL;
@@ -476,7 +574,6 @@ utf8_nstrstr_ignore_lower_case(const char *haystack, const char *needle)
 	return haystack;
 }
 
-
 bool
 utf8_isupper(const char *s)
 {
